User messages
-------------

User message has more complicate structure than “system” message. It contains:

* Time in [H:i:s] format
* Participant name: "You", "Talker" or "...". Name "..." is used if several messages from one user was sent
* Message body

For more information about style please follow to :ref:`mockups <Mockups>` section.

